chdir

Function chdir 

pub unsafe extern "system" fn chdir(filename: *const c_char) -> c_int
chdir() changes the current working directory of the calling process to the directory specified in path.

RETURN VALUE

On success, zero is returned. On error, -1 is returned, and errno is set to indicate the error.

Read the docs here