fchdir

Function fchdir 

pub unsafe extern "system" fn fchdir(fd: c_uint) -> c_int
fchdir() is identical to chdir(); the only difference is that the directory is given as an open file descriptor.

RETURN VALUE

On success, zero is returned. On error, -1 is returned, and errno is set to indicate the error.

Read the docs here