fcntl

Function fcntl 

pub unsafe extern "system" fn fcntl(
    fd: c_uint,
    cmd: c_uint,
    arg: c_uint,
) -> c_long
fcntl() performs one of the operations described below on the open file descriptor fd. The operation is determined by op.

RETURN VALUE

For a successful call, the return value depends on the operation. On error, -1 is returned, and errno is set to indicate the error.

ERRORS

EACCES(13), EAGAIN(11), EBADF(9), EINVAL(22).

Read the docs here