rename

Function rename 

pub unsafe extern "system" fn rename(
    oldname: *const c_char,
    newname: *const c_char,
) -> c_uint
rename() renames a file, moving it between directories if required. Any other hard links to the file (as created using link(2)) are unaffected. Open file descriptors for oldpath are also unaffected.

RETURN VALUE

On success, zero is returned. On error, -1 is returned, and errno is set to indicate the error.

Read the docs here