This module supports all the 64 bit arch syscalls
Functions
- accept⚠
- bind⚠
- brk⚠
- brk() and sbrk() change the location of the program break, which
defines the end of the process’s data segment.
- chdir⚠
- chdir() changes the current working directory of the calling process to the directory specified in path.
- chmod⚠
- chown⚠
- close⚠
- close() closes a file descriptor, so that it no longer refers to
any file and may be reused.
- connect⚠
- creat⚠
- execve⚠
- exit⚠
- exit() terminates the calling process “immediately”.
- fchdir⚠
- fchdir() is identical to chdir(); the only difference is that the directory is given as an open file descriptor.
- fchmod⚠
- fcntl⚠
- fcntl() performs one of the operations described below on the open file descriptor fd. The operation is determined by op.
- fdatasync⚠
- fdatasync() is similar to fsync(), but does not flush modified metadata unless that metadata is needed in order to allow a subsequent data retrieval to be correctly handled. For example, changes to st_atime or st_mtime (respectively, time of last access and time of last modification; see inode(7)) do not require flushing because they are not necessary for a subsequent data read to be handled correctly. On the other hand, a change to the file size (st_size, as made by say ftruncate(2)), would require a metadata flush.
- flock⚠
- fork⚠
- fork() creates a new process by duplicating the calling process. The new process is referred to as the child process. The calling process is referred to as the parent process.
- fsync⚠
- fsync() transfers (“flushes”) all modified in-core data of (i.e., modified buffer cache pages for) the file referred to by the file descriptor fd to the disk device (or other permanent storage device) so that all changed information can be retrieved even if the system crashes or is rebooted. This includes writing through or flushing a disk cache if present. The call blocks until the device reports that the transfer has completed.
- ftruncate⚠
- getcwd⚠
- The getcwd() function copies an absolute pathname of the current working directory to the array pointed to by buf, which is of length size.
- getegid⚠
- geteuid⚠
- getgid⚠
- getpgrp⚠
- getpid⚠
- getpid() returns the process ID (PID) of the calling process.
(This is often used by routines that generate unique temporary
filenames.)
- getppid⚠
- getuid⚠
- kill⚠
- The kill() system call can be used to send any signal to any process group or process.
- link⚠
- listen⚠
- lseek⚠
- mkdir⚠
- mkdir() attempts to create a directory named path.
- mmap⚠
- mount⚠
- mprotect⚠
- munmap⚠
- newfstat⚠
- newlstat⚠
- newstat⚠
- open⚠
- The open() system call opens the file specified by pathname. If
the specified file does not exist, it may optionally (if O_CREAT
is specified in flags) be created by open().
- poll⚠
- read⚠
- read() attempts to read up to count bytes from file descriptor fd
into the buffer starting at buf.
- readlink⚠
- rename⚠
- rename() renames a file, moving it between directories if required. Any other hard links to the file (as created using link(2)) are unaffected. Open file descriptors for oldpath are also unaffected.
- rmdir⚠
- setgid⚠
- setpgid⚠
- setsid⚠
- setuid⚠
- socket⚠
- swapoff⚠
- swapon⚠
- symlink⚠
- syncfs⚠
- syncfs() is like sync(), but synchronizes just the filesystem containing file referred to by the open file descriptor fd.
- syslog⚠
- truncate⚠
- umask⚠
- umount⚠
- unlink⚠
- vfork⚠
- vfork - create a child process and block parent
- write⚠
- write() writes up to count bytes from the buffer starting at buf
to the file referred to by the file descriptor fd.